@@ -6,13 +6,14 @@ Created on Sat Oct 24 18:24:20 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.3.0'
-__release__ = 20220919
+__version__ = '0.4.2'
+__release__ = 20220921
 __all__ = ['units', 'convert']
 
+
 from .units.define import units
-from ._convert import convertUnit
-from ._convert import convertUnit as convert
+from .convert import convertUnit
+from .convert import convertUnit as convert
 
 def print_path(switch=None):
     from ._database import unitsNetwork
