@@ -5,14 +5,16 @@ Created on Sat Oct 24 14:34:59 2020
 
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
-__version__ = '0.1.1'
-__release__ = 20220803
 
-from .._dictionaries import dictionary
-from .._unit import _units
+__version__ = '0.4.0'
+__release__ = 20220920
+__all__ = ['rate', 'speed', 'velocity']
+
+from ..dictionaries import dictionary
+from ..unit_class import unit
 
 
-class rate(_units):
+class rate(unit):
     classUnits = dictionary['rate']
     def __init__(self, value, units):
         self.name = 'rate'
@@ -20,7 +22,8 @@ class rate(_units):
         self.value = self.checkValue(value)
         self.unit = self.checkUnit(units)
 
-class speed(_units):
+
+class speed(unit):
     classUnits = dictionary['speed']
     def __init__(self, value, units):
         self.name = 'speed'
@@ -28,5 +31,6 @@ class speed(_units):
         self.value = self.checkValue(value)
         self.unit = self.checkUnit(units)
 
+
 def velocity(value, units):
     return speed(value, units)
\ No newline at end of file
