@@ -5,14 +5,16 @@ Created on Sat Oct 24 14:34:59 2020
 
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
-__version__ = '0.1.1'
-__release__ = 20220803
 
-from .._dictionaries import dictionary
-from .._unit import _units
+__version__ = '0.4.0'
+__release__ = 20220920
+__all__ = ['density', 'volumeRatio', 'productivityIndex', 'pressureGradient']
+
+from ..dictionaries import dictionary
+from ..unit_class import unit
 
 
-class density(_units):
+class density(unit):
     classUnits = dictionary['density']
     def __init__(self, value, units):
         self.name = 'density'
@@ -21,7 +23,7 @@ class density(_units):
         self.unit = self.checkUnit(units)
 
 
-class volumeRatio(_units):
+class volumeRatio(unit):
     classUnits = dictionary['volumeRatio']
     def __init__(self, value, units):
         self.name = 'volumeRatio'
@@ -30,7 +32,7 @@ class volumeRatio(_units):
         self.unit = self.checkUnit(units)
 
 
-class productivityIndex(_units):
+class productivityIndex(unit):
     classUnits = dictionary['productivityIndex']
     def __init__(self, value, units) :
         self.name = 'productivityIndex'
@@ -38,11 +40,10 @@ class productivityIndex(_units):
         self.value = self.checkValue(value)
         self.unit = self.checkUnit(units)
 
-class pressureGradient(_units):
+class pressureGradient(unit):
     classUnits = dictionary['pressureGradient']
     def __init__(self, value, units) :
         self.name = 'pressureGradient'
         self.kind = pressureGradient
         self.value = self.checkValue(value)
-        self.unit = self.checkUnit(units)
-
+        self.unit = self.checkUnit(units)
\ No newline at end of file
